==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkCompositeDataDisplayAttributes.java <==
// java wrapper for vtkCompositeDataDisplayAttributes object
//

package vtk;
import vtk.*;

public class vtkCompositeDataDisplayAttributes extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean HasBlockVisibilities_2();
  public boolean HasBlockVisibilities()
    { return HasBlockVisibilities_2(); }

  private native void SetBlockVisibility_3(int id0,boolean id1);
  public void SetBlockVisibility(int id0,boolean id1)
    { SetBlockVisibility_3(id0,id1); }

  private native boolean GetBlockVisibility_4(int id0);
  public boolean GetBlockVisibility(int id0)
    { return GetBlockVisibility_4(id0); }

  private native boolean HasBlockVisibility_5(int id0);
  public boolean HasBlockVisibility(int id0)
    { return HasBlockVisibility_5(id0); }

  private native void RemoveBlockVisibility_6(int id0);
  public void RemoveBlockVisibility(int id0)
    { RemoveBlockVisibility_6(id0); }

  private native void RemoveBlockVisibilites_7();
  public void RemoveBlockVisibilites()
    { RemoveBlockVisibilites_7(); }

  private native void SetBlockColor_8(int id0,double id1[]);
  public void SetBlockColor(int id0,double id1[])
    { SetBlockColor_8(id0,id1); }

  private native void GetBlockColor_9(int id0,double id1[]);
  public void GetBlockColor(int id0,double id1[])
    { GetBlockColor_9(id0,id1); }

  private native boolean HasBlockColors_10();
  public boolean HasBlockColors()
    { return HasBlockColors_10(); }

  private native boolean HasBlockColor_11(int id0);
  public boolean HasBlockColor(int id0)
    { return HasBlockColor_11(id0); }

  private native void RemoveBlockColor_12(int id0);
  public void RemoveBlockColor(int id0)
    { RemoveBlockColor_12(id0); }

  private native void RemoveBlockColors_13();
  public void RemoveBlockColors()
    { RemoveBlockColors_13(); }

  private native void SetBlockOpacity_14(int id0,double id1);
  public void SetBlockOpacity(int id0,double id1)
    { SetBlockOpacity_14(id0,id1); }

  private native double GetBlockOpacity_15(int id0);
  public double GetBlockOpacity(int id0)
    { return GetBlockOpacity_15(id0); }

  private native boolean HasBlockOpacities_16();
  public boolean HasBlockOpacities()
    { return HasBlockOpacities_16(); }

  private native boolean HasBlockOpacity_17(int id0);
  public boolean HasBlockOpacity(int id0)
    { return HasBlockOpacity_17(id0); }

  private native void RemoveBlockOpacity_18(int id0);
  public void RemoveBlockOpacity(int id0)
    { RemoveBlockOpacity_18(id0); }

  private native void RemoveBlockOpacities_19();
  public void RemoveBlockOpacities()
    { RemoveBlockOpacities_19(); }

  public vtkCompositeDataDisplayAttributes() { super(); }

  public vtkCompositeDataDisplayAttributes(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkCompositeDataDisplayAttributes.java <==
// java wrapper for vtkCompositeDataDisplayAttributes object
//

package vtk;
import vtk.*;

public class vtkCompositeDataDisplayAttributes extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean HasBlockVisibilities_2();
  public boolean HasBlockVisibilities()
    { return HasBlockVisibilities_2(); }

  private native void SetBlockVisibility_3(int id0,boolean id1);
  public void SetBlockVisibility(int id0,boolean id1)
    { SetBlockVisibility_3(id0,id1); }

  private native boolean GetBlockVisibility_4(int id0);
  public boolean GetBlockVisibility(int id0)
    { return GetBlockVisibility_4(id0); }

  private native boolean HasBlockVisibility_5(int id0);
  public boolean HasBlockVisibility(int id0)
    { return HasBlockVisibility_5(id0); }

  private native void RemoveBlockVisibility_6(int id0);
  public void RemoveBlockVisibility(int id0)
    { RemoveBlockVisibility_6(id0); }

  private native void RemoveBlockVisibilites_7();
  public void RemoveBlockVisibilites()
    { RemoveBlockVisibilites_7(); }

  private native void SetBlockColor_8(int id0,double id1[]);
  public void SetBlockColor(int id0,double id1[])
    { SetBlockColor_8(id0,id1); }

  private native void GetBlockColor_9(int id0,double id1[]);
  public void GetBlockColor(int id0,double id1[])
    { GetBlockColor_9(id0,id1); }

  private native boolean HasBlockColors_10();
  public boolean HasBlockColors()
    { return HasBlockColors_10(); }

  private native boolean HasBlockColor_11(int id0);
  public boolean HasBlockColor(int id0)
    { return HasBlockColor_11(id0); }

  private native void RemoveBlockColor_12(int id0);
  public void RemoveBlockColor(int id0)
    { RemoveBlockColor_12(id0); }

  private native void RemoveBlockColors_13();
  public void RemoveBlockColors()
    { RemoveBlockColors_13(); }

  private native void SetBlockOpacity_14(int id0,double id1);
  public void SetBlockOpacity(int id0,double id1)
    { SetBlockOpacity_14(id0,id1); }

  private native double GetBlockOpacity_15(int id0);
  public double GetBlockOpacity(int id0)
    { return GetBlockOpacity_15(id0); }

  private native boolean HasBlockOpacities_16();
  public boolean HasBlockOpacities()
    { return HasBlockOpacities_16(); }

  private native boolean HasBlockOpacity_17(int id0);
  public boolean HasBlockOpacity(int id0)
    { return HasBlockOpacity_17(id0); }

  private native void RemoveBlockOpacity_18(int id0);
  public void RemoveBlockOpacity(int id0)
    { RemoveBlockOpacity_18(id0); }

  private native void RemoveBlockOpacities_19();
  public void RemoveBlockOpacities()
    { RemoveBlockOpacities_19(); }

  private native void ComputeVisibleBounds_20(vtkCompositeDataDisplayAttributes id0,vtkDataObject id1,double id2[]);
  public void ComputeVisibleBounds(vtkCompositeDataDisplayAttributes id0,vtkDataObject id1,double id2[])
    { ComputeVisibleBounds_20(id0,id1,id2); }

  public vtkCompositeDataDisplayAttributes() { super(); }

  public vtkCompositeDataDisplayAttributes(long id) { super(id); }
  public native long   VTKInit();

}
